ConservativeAlignerPredictor

predictor.ConservativeAlignerPredictor(
    feedback=None,
    *,
    min_prediction_score=60.0,
    score_tolerance_from_best=5.0,
    require_stable=True,
)

Conservative predictor that keeps only high-confidence stable predictions.

This strategy runs the default prediction logic first, then narrows the predicted candidates per thematic feature to reduce ambiguity.