DiffMetric

enums.DiffMetric()

Metrics to quantify the change between thematic and reference data.

Attributes

Name Type Description
AREA_CHANGE str Absolute change in area (m²).
AREA_PERCENTAGE_CHANGE str Relative change in area (%).
SYMMETRICAL_AREA_CHANGE str The area of the symmetric difference (XOR).
SYMMETRICAL_AREA_PERCENTAGE_CHANGE str Symmetric difference as a percentage of original area.
LENGTH_CHANGE str Change in length.
LENGTH_PERCENTAGE_CHANGE str Relative change in length.
LENGTH_REMOVED str The length of segments removed during processing.
LENGTH_ADDED_AND_REMOVED str The length of segments added and removed during processing.
TOTAL_DISTANCE str Sum of displacement of all vertices.
REFERENCE_USAGE str The extent of reference boundaries utilized (m or m²).