AlignerInputType
enums.AlignerInputType()Role of an input dataset in the aligner pipeline.
Attributes
| Name | Type | Description |
|---|---|---|
| THEMATIC | str |
The input dataset that is being aligned. |
| REFERENCE | str |
The target dataset used as alignment reference. |
Role of an input dataset in the aligner pipeline.
| Name | Type | Description |
|---|---|---|
| THEMATIC | str |
The input dataset that is being aligned. |
| REFERENCE | str |
The target dataset used as alignment reference. |