OpenDomainStrategy
enums.OpenDomainStrategy()Strategies for thematic areas that are not covered by the reference layer.
Attributes
| Name | Type | Description |
|---|---|---|
| EXCLUDE | str |
Exclude open-domain parts from the resulting geometry. |
| AS_IS | str |
Keep open-domain parts unchanged. |
| SNAP_INNER_SIDE | str |
Snap open-domain parts to inner reference boundaries. |
| SNAP_ALL_SIDE | str |
Snap open-domain parts to both inner and outer sides where applicable. |
| SNAP_PREFER_VERTICES | str |
Snap with preference for reference vertices. |
| SNAP_PREFER_ENDS_AND_ANGLES | str |
Snap with preference for reference vertices; first ends, then angles, then other vertices. |
| SNAP_NO_PREFERENCE | str |
Snap without vertex/edge preference. |
| SNAP_ONLY_VERTICES | str |
Restrict snapping targets to reference vertices only. |